#!/usr/bin/env python3
import glob
import pathlib
import sys
import subprocess
import os

env_path = pathlib.Path(__file__).parent / '.venv'
python_path = env_path / 'bin' / 'python3'

if not env_path.exists():
    subprocess.check_call([
        'uv', 'venv', '--seed', '--offline',
        str(env_path)
    ])

    subprocess.check_call([
        'uv',
        'pip',
        'install',
        '-p',
        python_path,
        '--offline',
        'uv',
    ])

    subprocess.check_call([
        python_path,
        '-m',
        'uv', 'pip', 'install',
        '--offline',
        'build', 'setuptools', 'meson-python', 'pybind11',
    ])

    early_wheels = glob.glob(
        str(
            pathlib.Path(__file__).parent / 'deps' / 'dist' / 'early' / '*.whl'
        )
    )
    if len(early_wheels) > 0:
        subprocess.check_call([
            python_path,
            '-m',
            'uv', 'pip', 'install',
            '--offline',
            *early_wheels,
        ])


if __name__ == '__main__':
    if pathlib.Path(sys.executable).absolute() != python_path.absolute():
        os.execv(
            str(python_path),
            [
                str(python_path),
                *sys.argv,
            ]
        )

    os.execv(
        str(python_path),
        [
            str(python_path),
            pathlib.Path(__file__).parent / 'cli.py',
            *sys.argv[1:],
        ]
    )